@@ -39,9 +39,12 @@ void Controller::toggleState() {
     }
 }
 
-void Controller::setLanguage() {
+QString Controller::getLanguage() {
     QMap<QString, QString> langs;
     langs["German"] = "de";
+    langs["Deutsch"] = "de";
+
+    QString langCode = "en";
 
     QSqlDatabase db;
     db = QSqlDatabase::addDatabase("QSQLITE");
@@ -57,14 +60,10 @@ void Controller::setLanguage() {
             language = query.value(0).toString();
         }
 //        qDebug() << language;
-        QString langCode = langs.value(language, "en");
-        if (langCode != "en") {
-            QTranslator translator;
-            if (translator.load("qml_" + langCode, "/opt/usr/share/qmltube/qml/qmltube/i18n")) {
-                QCoreApplication::installTranslator(&translator);
-            }
-        }
+        langCode = langs.value(language, "en");
     }
+//    qDebug() << langCode;
+    return langCode;
 }
 
 void Controller::setOrientation(const QString &orient) {
