@@ -18,7 +18,7 @@ public:
 
 public slots:
 
-    void setLanguage();
+    QString getLanguage();
     void setOrientation(const QString &orient);
     bool kmPlayerInstalled();
     bool xTubeInstalled();
