@@ -21,7 +21,6 @@ int main(int argc, char *argv[])
 
     QDeclarativeContext *context = viewer.rootContext();
     Controller ct;
-    ct.setLanguage();
     ct.setView(&viewer);
     YouTube yt;
     Sharing sh;
@@ -53,6 +52,14 @@ int main(int argc, char *argv[])
     //    viewer.setViewport(new QGLWidget());
 #endif
 
+    QString locale = ct.getLanguage();
+
+    QTranslator translator;
+
+    if (translator.load("/opt/usr/share/qmltube/qml/qmltube/i18n/qml_" + locale)) {
+        app.installTranslator(&translator);
+    }
+
     viewer.setMainQmlFile(QLatin1String("qml/qmltube/main.qml"));
     viewer.showFullScreen();
 
