@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="36"/>
-        <source>cuteTube-QML - 0.3.10</source>
+        <source>cuteTube-QML - 0.4.1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -64,7 +64,7 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../AddCommentDialog.qml" line="14"/>
+        <location filename="../AddCommentDialog.qml" line="15"/>
         <source>Share Via </source>
         <translation></translation>
     </message>
@@ -152,22 +152,22 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="124"/>
+        <location filename="../../../controller.cpp" line="123"/>
         <source>Video deleted from device</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="127"/>
+        <location filename="../../../controller.cpp" line="126"/>
         <source>Unable to delete video</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="131"/>
+        <location filename="../../../controller.cpp" line="130"/>
         <source>Video not found</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="186"/>
+        <location filename="../../../controller.cpp" line="185"/>
         <source>Copied to clipboard</source>
         <translation type="unfinished"></translation>
     </message>
@@ -198,6 +198,7 @@
 <context>
     <name>DownloadManager</name>
     <message>
+        <location filename="../../../downloadmanager.cpp" line="37"/>
         <location filename="../../../downloadmanager.cpp" line="66"/>
         <location filename="../../../downloadmanager.cpp" line="159"/>
         <source>Failed</source>
@@ -225,37 +226,37 @@
 <context>
     <name>HomeView</name>
     <message>
-        <location filename="../HomeView.qml" line="131"/>
+        <location filename="../HomeView.qml" line="124"/>
         <source>Settings</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="131"/>
+        <location filename="../HomeView.qml" line="124"/>
         <source>Accounts</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="131"/>
+        <location filename="../HomeView.qml" line="124"/>
         <source>About</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="187"/>
+        <location filename="../HomeView.qml" line="180"/>
         <source>My Channel</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="215"/>
+        <location filename="../HomeView.qml" line="208"/>
         <source>Most Recent</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="243"/>
+        <location filename="../HomeView.qml" line="236"/>
         <source>Most Viewed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="271"/>
+        <location filename="../HomeView.qml" line="264"/>
         <source>Archive</source>
         <translation></translation>
     </message>
@@ -286,27 +287,37 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="157"/>
+        <location filename="../MyAccountView.qml" line="147"/>
+        <source>My Uploads</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../MyAccountView.qml" line="154"/>
         <source>Uploads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="185"/>
+        <location filename="../MyAccountView.qml" line="172"/>
+        <source>My Favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../MyAccountView.qml" line="179"/>
         <source>Favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="213"/>
+        <location filename="../MyAccountView.qml" line="204"/>
         <source>Playlists</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="241"/>
+        <location filename="../MyAccountView.qml" line="229"/>
         <source>Subscriptions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="256"/>
+        <location filename="../MyAccountView.qml" line="244"/>
         <source>Signed in as:</source>
         <translation></translation>
     </message>
@@ -378,12 +389,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../OAuthDialog.qml" line="33"/>
+        <location filename="../OAuthDialog.qml" line="26"/>
         <source>Error obtaining facebook authorisation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../OAuthDialog.qml" line="148"/>
+        <location filename="../OAuthDialog.qml" line="123"/>
         <source>Enter pin code</source>
         <translation type="unfinished"></translation>
     </message>
@@ -478,7 +489,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="185"/>
+        <location filename="../SearchBar.qml" line="176"/>
         <source>Order by:</source>
         <translation></translation>
     </message>
@@ -531,33 +542,39 @@
         <translation></translation>
     </message>
     <message>
+        <location filename="../SettingsDialog.qml" line="110"/>
         <location filename="../SettingsDialog.qml" line="257"/>
         <location filename="../SettingsDialog.qml" line="393"/>
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../SettingsDialog.qml" line="92"/>
         <location filename="../SettingsDialog.qml" line="283"/>
         <source>Playback Quality</source>
         <translation></translation>
     </message>
     <message>
+        <location filename="../SettingsDialog.qml" line="95"/>
         <location filename="../SettingsDialog.qml" line="301"/>
         <source>Download Quality</source>
         <translation></translation>
     </message>
     <message>
+        <location filename="../SettingsDialog.qml" line="98"/>
         <location filename="../SettingsDialog.qml" line="319"/>
         <source>Start Downloads</source>
         <translation></translation>
     </message>
     <message>
+        <location filename="../SettingsDialog.qml" line="104"/>
         <location filename="../SettingsDialog.qml" line="357"/>
         <source>Screen Orientation</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="107"/>
         <location filename="../SettingsDialog.qml" line="375"/>
         <source>Media Player</source>
         <translation></translation>
@@ -577,6 +594,7 @@
     <message>
         <location filename="../SettingsDialog.qml" line="17"/>
         <location filename="../SettingsDialog.qml" line="34"/>
+        <location filename="../SettingsDialog.qml" line="58"/>
         <source>Automatically</source>
         <translation type="unfinished"></translation>
     </message>
@@ -611,8 +629,25 @@
         <source>German</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="33"/>
+        <location filename="../SettingsDialog.qml" line="59"/>
+        <source>Queued</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="62"/>
+        <source>Paused</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="64"/>
+        <source>Your settings have been saved</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../SettingsDialog.qml" line="69"/>
+        <location filename="../SettingsDialog.qml" line="101"/>
         <source>Download Path</source>
         <translation type="unfinished"></translation>
     </message>
@@ -816,12 +851,12 @@
 <context>
     <name>UserInfoDialog</name>
     <message>
-        <location filename="../UserInfoDialog.qml" line="115"/>
+        <location filename="../UserInfoDialog.qml" line="111"/>
         <source>Subscribers</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserInfoDialog.qml" line="129"/>
+        <location filename="../UserInfoDialog.qml" line="125"/>
         <source>Videos</source>
         <translation></translation>
     </message>
@@ -902,102 +937,97 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="70"/>
+        <location filename="../VideoInfoView.qml" line="71"/>
         <source>Your comment has been added</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="73"/>
+        <location filename="../VideoInfoView.qml" line="74"/>
         <source>Your rating has been added</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="80"/>
+        <location filename="../VideoInfoView.qml" line="81"/>
         <source>Video shared on facebook</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="133"/>
+        <location filename="../VideoInfoView.qml" line="135"/>
         <source>Add to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="133"/>
+        <location filename="../VideoInfoView.qml" line="135"/>
         <source>Add to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="133"/>
+        <location filename="../VideoInfoView.qml" line="135"/>
         <source>Copy to clipboard</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="134"/>
-        <source>Share via twitter</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../VideoInfoView.qml" line="134"/>
+        <location filename="../VideoInfoView.qml" line="136"/>
         <source>Share via facebook</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="153"/>
-        <location filename="../VideoInfoView.qml" line="161"/>
-        <location filename="../VideoInfoView.qml" line="502"/>
-        <location filename="../VideoInfoView.qml" line="526"/>
-        <location filename="../VideoInfoView.qml" line="631"/>
+        <location filename="../VideoInfoView.qml" line="155"/>
+        <location filename="../VideoInfoView.qml" line="163"/>
+        <location filename="../VideoInfoView.qml" line="501"/>
+        <location filename="../VideoInfoView.qml" line="525"/>
+        <location filename="../VideoInfoView.qml" line="630"/>
         <source>You are not signed in to a YouTube account</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="303"/>
+        <location filename="../VideoInfoView.qml" line="302"/>
         <source>Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="342"/>
+        <location filename="../VideoInfoView.qml" line="341"/>
         <source>Comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="381"/>
+        <location filename="../VideoInfoView.qml" line="380"/>
         <source>Related</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="472"/>
-        <location filename="../VideoInfoView.qml" line="475"/>
+        <location filename="../VideoInfoView.qml" line="471"/>
+        <location filename="../VideoInfoView.qml" line="474"/>
         <source>By </source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="543"/>
+        <location filename="../VideoInfoView.qml" line="542"/>
         <source>Views</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="557"/>
+        <location filename="../VideoInfoView.qml" line="556"/>
         <source>Description</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="573"/>
+        <location filename="../VideoInfoView.qml" line="572"/>
         <source>Tags</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="643"/>
+        <location filename="../VideoInfoView.qml" line="642"/>
         <source>No comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="643"/>
+        <location filename="../VideoInfoView.qml" line="642"/>
         <source> comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="737"/>
+        <location filename="../VideoInfoView.qml" line="736"/>
         <source>No related videos</source>
         <translation></translation>
     </message>
@@ -1053,105 +1083,6 @@
         <translation></translation>
     </message>
 </context>
-<context>
-    <name>XHamsterInfoView</name>
-    <message>
-        <location filename="../XHamsterInfoView.qml" line="243"/>
-        <source>Info</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../XHamsterInfoView.qml" line="282"/>
-        <source>Related</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../XHamsterInfoView.qml" line="364"/>
-        <location filename="../XHamsterInfoView.qml" line="367"/>
-        <source>By </source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../XHamsterInfoView.qml" line="366"/>
-        <location filename="../XHamsterInfoView.qml" line="369"/>
-        <source> on </source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../XHamsterInfoView.qml" line="385"/>
-        <source>Views </source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../XHamsterInfoView.qml" line="391"/>
-        <source>Tags</source>
-        <translation></translation>
-    </message>
-</context>
-<context>
-    <name>XHamsterListView</name>
-    <message>
-        <location filename="../XHamsterListView.qml" line="162"/>
-        <source>Multi-select</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../XHamsterListView.qml" line="164"/>
-        <source>Download video</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../XHamsterListView.qml" line="200"/>
-        <source>No videos found</source>
-        <translation></translation>
-    </message>
-</context>
-<context>
-    <name>YouJizzInfoView</name>
-    <message>
-        <location filename="../YouJizzInfoView.qml" line="97"/>
-        <source>Copy to clipboard</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../YouJizzInfoView.qml" line="232"/>
-        <source>Info</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../YouJizzInfoView.qml" line="271"/>
-        <source>Related</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../YouJizzInfoView.qml" line="348"/>
-        <source>Views </source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../YouJizzInfoView.qml" line="354"/>
-        <source>Tags</source>
-        <translation></translation>
-    </message>
-</context>
-<context>
-    <name>YouJizzListView</name>
-    <message>
-        <location filename="../YouJizzListView.qml" line="149"/>
-        <source>Multi-select</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../YouJizzListView.qml" line="151"/>
-        <source>Download video</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../YouJizzListView.qml" line="187"/>
-        <source>No videos found</source>
-        <translation></translation>
-    </message>
-</context>
 <context>
     <name>YouTube</name>
     <message>
@@ -1247,6 +1178,7 @@
     <message>
         <location filename="../main.qml" line="185"/>
         <location filename="../main.qml" line="192"/>
+        <location filename="../main.qml" line="232"/>
         <source>Queued</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1256,12 +1188,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="348"/>
+        <location filename="../main.qml" line="380"/>
         <source>Most Recent</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="349"/>
+        <location filename="../main.qml" line="381"/>
         <source>Most Viewed</source>
         <translation></translation>
     </message>
@@ -1269,93 +1201,103 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../mainscripts.js" line="118"/>
+        <location filename="../scripts/mainscripts.js" line="18"/>
+        <source>Media Player</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../scripts/mainscripts.js" line="118"/>
         <source>My Channel</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="132"/>
+        <location filename="../scripts/mainscripts.js" line="132"/>
         <source>Archive</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="171"/>
+        <location filename="../scripts/mainscripts.js" line="171"/>
         <source>My Playlists</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="181"/>
+        <location filename="../scripts/mainscripts.js" line="181"/>
         <source>My Subscriptions</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="194"/>
+        <location filename="../scripts/mainscripts.js" line="194"/>
         <source>Video Info</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="203"/>
+        <location filename="../scripts/mainscripts.js" line="203"/>
         <source>Video Playback</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="213"/>
+        <location filename="../scripts/mainscripts.js" line="213"/>
         <source>Downloads</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="230"/>
+        <location filename="../scripts/mainscripts.js" line="221"/>
+        <source>date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../scripts/mainscripts.js" line="224"/>
+        <source>views</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../scripts/mainscripts.js" line="227"/>
+        <source>relevance</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../scripts/mainscripts.js" line="230"/>
+        <source>rating</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../scripts/mainscripts.js" line="237"/>
         <source>Search </source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>settings</name>
     <message>
-        <location filename="../settings.js" line="126"/>
-        <location filename="../settings.js" line="127"/>
+        <location filename="../scripts/settings.js" line="126"/>
+        <location filename="../scripts/settings.js" line="127"/>
         <source>High Quality</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings.js" line="128"/>
+        <location filename="../scripts/settings.js" line="128"/>
         <source>Paused</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings.js" line="130"/>
+        <location filename="../scripts/settings.js" line="130"/>
         <source>Automatic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings.js" line="131"/>
+        <location filename="../scripts/settings.js" line="131"/>
         <source>Media Player</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings.js" line="132"/>
+        <location filename="../scripts/settings.js" line="132"/>
         <source>Date</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings.js" line="133"/>
+        <location filename="../scripts/settings.js" line="133"/>
         <source>English</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>xtube</name>
-    <message>
-        <location filename="../xtube.js" line="18"/>
-        <location filename="../xtube.js" line="62"/>
-        <source>Search </source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../xtube.js" line="39"/>
-        <location filename="../xtube.js" line="82"/>
-        <source>Video Info</source>
-        <translation></translation>
-    </message>
-</context>
 </TS>
