@@ -8,9 +8,13 @@
         <translation type="obsolete">cuteTube-QML - 0.3.9 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="36"/>
         <source>cuteTube-QML - 0.3.10</source>
-        <translation type="unfinished">cuteTube-QML - 0.3.10 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.3.10 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="36"/>
+        <source>cuteTube-QML - 0.4.1</source>
+        <translation>cuteTube-QML - 0.4.1</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="48"/>
@@ -88,7 +92,7 @@
         <translation>Kommentieren</translation>
     </message>
     <message>
-        <location filename="../AddCommentDialog.qml" line="14"/>
+        <location filename="../AddCommentDialog.qml" line="15"/>
         <source>Share Via </source>
         <translation>Freigeben</translation>
     </message>
@@ -184,24 +188,24 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="124"/>
+        <location filename="../../../controller.cpp" line="123"/>
         <source>Video deleted from device</source>
-        <translation type="unfinished"></translation>
+        <translation>Video vom Gerät gelöscht</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="127"/>
+        <location filename="../../../controller.cpp" line="126"/>
         <source>Unable to delete video</source>
-        <translation type="unfinished"></translation>
+        <translation>Löschen des Videos nicht möglich</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="131"/>
+        <location filename="../../../controller.cpp" line="130"/>
         <source>Video not found</source>
-        <translation type="unfinished"></translation>
+        <translation>Video nicht gefunden</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="186"/>
+        <location filename="../../../controller.cpp" line="185"/>
         <source>Copied to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>In Zwischenablage kopiert</translation>
     </message>
 </context>
 <context>
@@ -209,41 +213,42 @@
     <message>
         <location filename="../DownloadListDelegate.qml" line="36"/>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation>Pausiert</translation>
     </message>
     <message>
         <location filename="../DownloadListDelegate.qml" line="36"/>
         <source>Queued</source>
-        <translation type="unfinished"></translation>
+        <translation>in Warteschlange</translation>
     </message>
     <message>
         <location filename="../DownloadListDelegate.qml" line="36"/>
         <source>Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehlgeschlagen</translation>
     </message>
     <message>
         <location filename="../DownloadListDelegate.qml" line="53"/>
         <source>Downloading</source>
-        <translation type="unfinished"></translation>
+        <translation>am Herrunterladen</translation>
     </message>
 </context>
 <context>
     <name>DownloadManager</name>
     <message>
+        <location filename="../../../downloadmanager.cpp" line="37"/>
         <location filename="../../../downloadmanager.cpp" line="66"/>
         <location filename="../../../downloadmanager.cpp" line="159"/>
         <source>Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehlgeschlagen</translation>
     </message>
     <message>
         <location filename="../../../downloadmanager.cpp" line="121"/>
         <source>Downloading</source>
-        <translation type="unfinished"></translation>
+        <translation>am Herrunterladen</translation>
     </message>
     <message>
         <location filename="../../../downloadmanager.cpp" line="156"/>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation>Pausiert</translation>
     </message>
 </context>
 <context>
@@ -261,37 +266,37 @@
 <context>
     <name>HomeView</name>
     <message>
-        <location filename="../HomeView.qml" line="131"/>
+        <location filename="../HomeView.qml" line="124"/>
         <source>Settings</source>
         <translation>Optionen</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="131"/>
+        <location filename="../HomeView.qml" line="124"/>
         <source>Accounts</source>
         <translation>Konto</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="131"/>
+        <location filename="../HomeView.qml" line="124"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="187"/>
+        <location filename="../HomeView.qml" line="180"/>
         <source>My Channel</source>
         <translation>Mein Kanal</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="215"/>
+        <location filename="../HomeView.qml" line="208"/>
         <source>Most Recent</source>
         <translation>Aktuellste Videos</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="243"/>
+        <location filename="../HomeView.qml" line="236"/>
         <source>Most Viewed</source>
         <translation>Meistgesehen</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="271"/>
+        <location filename="../HomeView.qml" line="264"/>
         <source>Archive</source>
         <translation>Archiv</translation>
     </message>
@@ -322,27 +327,37 @@
         <translation>Video hochladen</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="157"/>
+        <location filename="../MyAccountView.qml" line="147"/>
+        <source>My Uploads</source>
+        <translation>Mein Uploads</translation>
+    </message>
+    <message>
+        <location filename="../MyAccountView.qml" line="154"/>
         <source>Uploads</source>
         <translation>Uploads</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="185"/>
+        <location filename="../MyAccountView.qml" line="172"/>
+        <source>My Favourites</source>
+        <translation>Mein Favoriten</translation>
+    </message>
+    <message>
+        <location filename="../MyAccountView.qml" line="179"/>
         <source>Favourites</source>
         <translation>Favoriten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="213"/>
+        <location filename="../MyAccountView.qml" line="204"/>
         <source>Playlists</source>
         <translation>Wiedergabelisten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="241"/>
+        <location filename="../MyAccountView.qml" line="229"/>
         <source>Subscriptions</source>
         <translation>Abonnement</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="256"/>
+        <location filename="../MyAccountView.qml" line="244"/>
         <source>Signed in as:</source>
         <translation>Angemeldet als:</translation>
     </message>
@@ -415,17 +430,17 @@
     <message>
         <location filename="../OAuthDialog.qml" line="8"/>
         <source>Authorisation For </source>
-        <translation type="unfinished"></translation>
+        <translation>Angemeldet als </translation>
     </message>
     <message>
-        <location filename="../OAuthDialog.qml" line="33"/>
+        <location filename="../OAuthDialog.qml" line="26"/>
         <source>Error obtaining facebook authorisation</source>
-        <translation type="unfinished"></translation>
+        <translation>Anmeldung bei Facebook schlug fehl</translation>
     </message>
     <message>
-        <location filename="../OAuthDialog.qml" line="148"/>
+        <location filename="../OAuthDialog.qml" line="123"/>
         <source>Enter pin code</source>
-        <translation type="unfinished"></translation>
+        <translation>Pin Code eingeben</translation>
     </message>
 </context>
 <context>
@@ -498,27 +513,27 @@
         <location filename="../SearchBar.qml" line="116"/>
         <location filename="../SearchBar.qml" line="126"/>
         <source>Date</source>
-        <translation type="unfinished"></translation>
+        <translation>Datum</translation>
     </message>
     <message>
         <location filename="../SearchBar.qml" line="117"/>
         <location filename="../SearchBar.qml" line="119"/>
         <source>Relevance</source>
-        <translation type="unfinished"></translation>
+        <translation>Relevanz</translation>
     </message>
     <message>
         <location filename="../SearchBar.qml" line="120"/>
         <location filename="../SearchBar.qml" line="122"/>
         <source>Rating</source>
-        <translation type="unfinished"></translation>
+        <translation>Bewertung</translation>
     </message>
     <message>
         <location filename="../SearchBar.qml" line="123"/>
         <source>Views</source>
-        <translation type="unfinished">Aufrufe</translation>
+        <translation>Aufrufe</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="185"/>
+        <location filename="../SearchBar.qml" line="176"/>
         <source>Order by:</source>
         <translation>Sortieren nach:</translation>
     </message>
@@ -571,33 +586,39 @@
         <translation>Media Player</translation>
     </message>
     <message>
+        <location filename="../SettingsDialog.qml" line="110"/>
         <location filename="../SettingsDialog.qml" line="257"/>
         <location filename="../SettingsDialog.qml" line="393"/>
         <source>Language</source>
-        <translation type="unfinished"></translation>
+        <translation>Sprache</translation>
     </message>
     <message>
+        <location filename="../SettingsDialog.qml" line="92"/>
         <location filename="../SettingsDialog.qml" line="283"/>
         <source>Playback Quality</source>
         <translation>Wiedergabequalität</translation>
     </message>
     <message>
+        <location filename="../SettingsDialog.qml" line="95"/>
         <location filename="../SettingsDialog.qml" line="301"/>
         <source>Download Quality</source>
         <translation>Downloadqualität</translation>
     </message>
     <message>
+        <location filename="../SettingsDialog.qml" line="98"/>
         <location filename="../SettingsDialog.qml" line="319"/>
         <source>Start Downloads</source>
         <translation>Downloads starten</translation>
     </message>
     <message>
+        <location filename="../SettingsDialog.qml" line="104"/>
         <location filename="../SettingsDialog.qml" line="357"/>
         <source>Screen Orientation</source>
         <translation>Bildschirmausrichtung</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="107"/>
         <location filename="../SettingsDialog.qml" line="375"/>
         <source>Media Player</source>
         <translation>Media Player</translation>
@@ -606,60 +627,78 @@
         <location filename="../SettingsDialog.qml" line="15"/>
         <location filename="../SettingsDialog.qml" line="16"/>
         <source>Mobile</source>
-        <translation type="unfinished"></translation>
+        <translation>Mobil</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="15"/>
         <location filename="../SettingsDialog.qml" line="16"/>
         <source>High Quality</source>
-        <translation type="unfinished"></translation>
+        <translation>Hohe Qualität</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="17"/>
         <location filename="../SettingsDialog.qml" line="34"/>
+        <location filename="../SettingsDialog.qml" line="58"/>
         <source>Automatically</source>
-        <translation type="unfinished"></translation>
+        <translation>Automatisch</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="17"/>
         <location filename="../SettingsDialog.qml" line="37"/>
         <source>Manually</source>
-        <translation type="unfinished"></translation>
+        <translation>Manuell</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="18"/>
         <source>Automatic</source>
-        <translation type="unfinished"></translation>
+        <translation>Automatisch</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="18"/>
         <source>Landscape</source>
-        <translation type="unfinished"></translation>
+        <translation>Querformat</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="18"/>
         <source>Portrait</source>
-        <translation type="unfinished"></translation>
+        <translation>Hochformat</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="20"/>
         <source>English</source>
-        <translation type="unfinished"></translation>
+        <translation>Englisch</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="20"/>
         <source>German</source>
-        <translation type="unfinished"></translation>
+        <translation>Deutsch</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="33"/>
+        <location filename="../SettingsDialog.qml" line="59"/>
+        <source>Queued</source>
+        <translation>in Warteschlange</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="62"/>
+        <source>Paused</source>
+        <translation>Pausiert</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="64"/>
+        <source>Your settings have been saved</source>
+        <translation>Ihre Einstellungen wurden gespeichert</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="69"/>
+        <location filename="../SettingsDialog.qml" line="101"/>
         <source>Download Path</source>
-        <translation type="unfinished"></translation>
+        <translation>Downloadverzeichnis</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="72"/>
         <source>Download Location</source>
-        <translation type="unfinished"></translation>
+        <translation>Downloadverzeichnis</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="407"/>
@@ -672,7 +711,7 @@
     <message>
         <location filename="../../../sharing.cpp" line="75"/>
         <source>Error - Server repsonse is: </source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler - Serverantwort ist:</translation>
     </message>
 </context>
 <context>
@@ -828,7 +867,7 @@
     <message>
         <location filename="../UploadProgressDialog.qml" line="6"/>
         <source>Starting upload</source>
-        <translation type="unfinished"></translation>
+        <translation>Upload startet</translation>
     </message>
     <message>
         <location filename="../UploadProgressDialog.qml" line="34"/>
@@ -858,18 +897,18 @@
     <message>
         <location filename="../UploadProgressDialog.qml" line="119"/>
         <source>Upload is in progress</source>
-        <translation type="unfinished"></translation>
+        <translation>Upload in Arbeit</translation>
     </message>
 </context>
 <context>
     <name>UserInfoDialog</name>
     <message>
-        <location filename="../UserInfoDialog.qml" line="115"/>
+        <location filename="../UserInfoDialog.qml" line="111"/>
         <source>Subscribers</source>
         <translation>Abonnenten</translation>
     </message>
     <message>
-        <location filename="../UserInfoDialog.qml" line="129"/>
+        <location filename="../UserInfoDialog.qml" line="125"/>
         <source>Videos</source>
         <translation>Videos</translation>
     </message>
@@ -950,102 +989,97 @@
         <translation>Keine Beschreibung</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="70"/>
+        <location filename="../VideoInfoView.qml" line="71"/>
         <source>Your comment has been added</source>
         <translation>Dein Kommentar wurde hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="73"/>
+        <location filename="../VideoInfoView.qml" line="74"/>
         <source>Your rating has been added</source>
         <translation>Deine Bewertung wurde hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="80"/>
+        <location filename="../VideoInfoView.qml" line="81"/>
         <source>Video shared on facebook</source>
-        <translation type="unfinished"></translation>
+        <translation>Video auf Facebook freigegeben</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="133"/>
+        <location filename="../VideoInfoView.qml" line="135"/>
         <source>Add to favourites</source>
         <translation>Zu Favoriten hinzufügen</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="133"/>
+        <location filename="../VideoInfoView.qml" line="135"/>
         <source>Add to playlist</source>
         <translation>Zur Wiedergabeliste hinzufügen</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="133"/>
+        <location filename="../VideoInfoView.qml" line="135"/>
         <source>Copy to clipboard</source>
         <translation>In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="134"/>
-        <source>Share via twitter</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../VideoInfoView.qml" line="134"/>
+        <location filename="../VideoInfoView.qml" line="136"/>
         <source>Share via facebook</source>
-        <translation type="unfinished"></translation>
+        <translation>Auf Facebook freigeben</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="153"/>
-        <location filename="../VideoInfoView.qml" line="161"/>
-        <location filename="../VideoInfoView.qml" line="502"/>
-        <location filename="../VideoInfoView.qml" line="526"/>
-        <location filename="../VideoInfoView.qml" line="631"/>
+        <location filename="../VideoInfoView.qml" line="155"/>
+        <location filename="../VideoInfoView.qml" line="163"/>
+        <location filename="../VideoInfoView.qml" line="501"/>
+        <location filename="../VideoInfoView.qml" line="525"/>
+        <location filename="../VideoInfoView.qml" line="630"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Nicht bei einem YouTube Konto angemeldet</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="303"/>
+        <location filename="../VideoInfoView.qml" line="302"/>
         <source>Info</source>
         <translation>Info</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="342"/>
+        <location filename="../VideoInfoView.qml" line="341"/>
         <source>Comments</source>
         <translation>Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="381"/>
+        <location filename="../VideoInfoView.qml" line="380"/>
         <source>Related</source>
         <translation>Ähnliche</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="472"/>
-        <location filename="../VideoInfoView.qml" line="475"/>
+        <location filename="../VideoInfoView.qml" line="471"/>
+        <location filename="../VideoInfoView.qml" line="474"/>
         <source>By </source>
         <translation>Von </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="543"/>
+        <location filename="../VideoInfoView.qml" line="542"/>
         <source>Views</source>
         <translation>Aufrufe</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="557"/>
+        <location filename="../VideoInfoView.qml" line="556"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="573"/>
+        <location filename="../VideoInfoView.qml" line="572"/>
         <source>Tags</source>
         <translation>Tags</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="643"/>
+        <location filename="../VideoInfoView.qml" line="642"/>
         <source>No comments</source>
         <translation>Keine Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="643"/>
+        <location filename="../VideoInfoView.qml" line="642"/>
         <source> comments</source>
         <translation>Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="737"/>
+        <location filename="../VideoInfoView.qml" line="736"/>
         <source>No related videos</source>
         <translation>Keine ähnlichen Videos</translation>
     </message>
@@ -1104,100 +1138,81 @@
 <context>
     <name>XHamsterInfoView</name>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="243"/>
         <source>Info</source>
-        <translation>Info</translation>
+        <translation type="obsolete">Info</translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="282"/>
         <source>Related</source>
-        <translation>Ähnliche</translation>
+        <translation type="obsolete">Ähnliche</translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="364"/>
-        <location filename="../XHamsterInfoView.qml" line="367"/>
         <source>By </source>
-        <translation>Von </translation>
+        <translation type="obsolete">Von </translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="366"/>
-        <location filename="../XHamsterInfoView.qml" line="369"/>
         <source> on </source>
-        <translation> am </translation>
+        <translation type="obsolete"> am </translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="385"/>
         <source>Views </source>
-        <translation>Aufrufe</translation>
+        <translation type="obsolete">Aufrufe</translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="391"/>
         <source>Tags</source>
-        <translation>Tags</translation>
+        <translation type="obsolete">Tags</translation>
     </message>
 </context>
 <context>
     <name>XHamsterListView</name>
     <message>
-        <location filename="../XHamsterListView.qml" line="162"/>
         <source>Multi-select</source>
-        <translation>Mehrfachauswahl</translation>
+        <translation type="obsolete">Mehrfachauswahl</translation>
     </message>
     <message>
-        <location filename="../XHamsterListView.qml" line="164"/>
         <source>Download video</source>
-        <translation>Video herrunterladen</translation>
+        <translation type="obsolete">Video herrunterladen</translation>
     </message>
     <message>
-        <location filename="../XHamsterListView.qml" line="200"/>
         <source>No videos found</source>
-        <translation>Keine Videos gefunden</translation>
+        <translation type="obsolete">Keine Videos gefunden</translation>
     </message>
 </context>
 <context>
     <name>YouJizzInfoView</name>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="97"/>
         <source>Copy to clipboard</source>
-        <translation>In Zwischenablage kopieren</translation>
+        <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="232"/>
         <source>Info</source>
-        <translation>Info</translation>
+        <translation type="obsolete">Info</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="271"/>
         <source>Related</source>
-        <translation>Ähnliche</translation>
+        <translation type="obsolete">Ähnliche</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="348"/>
         <source>Views </source>
-        <translation>Aufrufe</translation>
+        <translation type="obsolete">Aufrufe</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="354"/>
         <source>Tags</source>
-        <translation>Tags</translation>
+        <translation type="obsolete">Tags</translation>
     </message>
 </context>
 <context>
     <name>YouJizzListView</name>
     <message>
-        <location filename="../YouJizzListView.qml" line="149"/>
         <source>Multi-select</source>
-        <translation>Mehrfachauswahl</translation>
+        <translation type="obsolete">Mehrfachauswahl</translation>
     </message>
     <message>
-        <location filename="../YouJizzListView.qml" line="151"/>
         <source>Download video</source>
-        <translation>Video herrunterladen</translation>
+        <translation type="obsolete">Video herrunterladen</translation>
     </message>
     <message>
-        <location filename="../YouJizzListView.qml" line="187"/>
         <source>No videos found</source>
-        <translation>Keine Videos gefunden</translation>
+        <translation type="obsolete">Keine Videos gefunden</translation>
     </message>
 </context>
 <context>
@@ -1205,49 +1220,49 @@
     <message>
         <location filename="../../../youtube.cpp" line="39"/>
         <source>Error obtaining access token</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler beim Zugangscode</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="49"/>
         <source>Authentication failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Autorisierung schlug fehl</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="52"/>
         <source>You are signed in to YouTube as &apos;</source>
-        <translation type="unfinished"></translation>
+        <translation>Bei YouTube angemeldet als &apos;</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="114"/>
         <location filename="../../../youtube.cpp" line="220"/>
         <source>Error - Server repsonse is: </source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler - Serverantwort ist:</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="164"/>
         <location filename="../../../youtube.cpp" line="172"/>
         <source>Upload aborted</source>
-        <translation type="unfinished"></translation>
+        <translation>Upload abgebrochen</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="179"/>
         <source>Upload interrupted. Attempting to resume...</source>
-        <translation type="unfinished"></translation>
+        <translation>Upload unterbrochen. Versuche wiederaufnahme...</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="183"/>
         <source>Upload failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Upload fehlgeschlagen</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="189"/>
         <source>Upload is completed</source>
-        <translation type="unfinished"></translation>
+        <translation>Upload ist komplett</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="379"/>
         <source>Error: Unable to retrieve video</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler: Kann Video nicht empfangen</translation>
     </message>
 </context>
 <context>
@@ -1280,7 +1295,7 @@
     <message>
         <location filename="../main.qml" line="162"/>
         <source>Converting</source>
-        <translation type="unfinished"></translation>
+        <translation>Konvertiere</translation>
     </message>
     <message>
         <location filename="../main.qml" line="171"/>
@@ -1295,21 +1310,22 @@
     <message>
         <location filename="../main.qml" line="185"/>
         <location filename="../main.qml" line="192"/>
+        <location filename="../main.qml" line="232"/>
         <source>Queued</source>
-        <translation type="unfinished"></translation>
+        <translation>in Warteschlange</translation>
     </message>
     <message>
         <location filename="../main.qml" line="200"/>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="348"/>
+        <location filename="../main.qml" line="380"/>
         <source>Most Recent</source>
         <translation>Aktuellste Videos</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="349"/>
+        <location filename="../main.qml" line="381"/>
         <source>Most Viewed</source>
         <translation>Meistgesehen</translation>
     </message>
@@ -1317,42 +1333,67 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../mainscripts.js" line="118"/>
+        <location filename="../scripts/mainscripts.js" line="18"/>
+        <source>Media Player</source>
+        <translation>Media Player</translation>
+    </message>
+    <message>
+        <location filename="../scripts/mainscripts.js" line="118"/>
         <source>My Channel</source>
         <translation>Mein Kanal</translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="132"/>
+        <location filename="../scripts/mainscripts.js" line="132"/>
         <source>Archive</source>
         <translation>Archiv</translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="171"/>
+        <location filename="../scripts/mainscripts.js" line="171"/>
         <source>My Playlists</source>
         <translation>Mein Wiedergabelisten</translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="181"/>
+        <location filename="../scripts/mainscripts.js" line="181"/>
         <source>My Subscriptions</source>
         <translation>Mein Abonnement</translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="194"/>
+        <location filename="../scripts/mainscripts.js" line="194"/>
         <source>Video Info</source>
         <translation>Video Info</translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="203"/>
+        <location filename="../scripts/mainscripts.js" line="203"/>
         <source>Video Playback</source>
         <translation>Video abspielen</translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="213"/>
+        <location filename="../scripts/mainscripts.js" line="213"/>
         <source>Downloads</source>
         <translation>Downloads</translation>
     </message>
     <message>
-        <location filename="../mainscripts.js" line="230"/>
+        <location filename="../scripts/mainscripts.js" line="221"/>
+        <source>date</source>
+        <translation>datum</translation>
+    </message>
+    <message>
+        <location filename="../scripts/mainscripts.js" line="224"/>
+        <source>views</source>
+        <translation>aufrufe</translation>
+    </message>
+    <message>
+        <location filename="../scripts/mainscripts.js" line="227"/>
+        <source>relevance</source>
+        <translation>relevanz</translation>
+    </message>
+    <message>
+        <location filename="../scripts/mainscripts.js" line="230"/>
+        <source>rating</source>
+        <translation>bewertung</translation>
+    </message>
+    <message>
+        <location filename="../scripts/mainscripts.js" line="237"/>
         <source>Search </source>
         <translation>Suchlauf</translation>
     </message>
@@ -1360,50 +1401,46 @@
 <context>
     <name>settings</name>
     <message>
-        <location filename="../settings.js" line="126"/>
-        <location filename="../settings.js" line="127"/>
+        <location filename="../scripts/settings.js" line="126"/>
+        <location filename="../scripts/settings.js" line="127"/>
         <source>High Quality</source>
-        <translation type="unfinished"></translation>
+        <translation>Hohe Qualität</translation>
     </message>
     <message>
-        <location filename="../settings.js" line="128"/>
+        <location filename="../scripts/settings.js" line="128"/>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../settings.js" line="130"/>
+        <location filename="../scripts/settings.js" line="130"/>
         <source>Automatic</source>
-        <translation type="unfinished"></translation>
+        <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../settings.js" line="131"/>
+        <location filename="../scripts/settings.js" line="131"/>
         <source>Media Player</source>
-        <translation type="unfinished">Media Player</translation>
+        <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../settings.js" line="132"/>
+        <location filename="../scripts/settings.js" line="132"/>
         <source>Date</source>
-        <translation type="unfinished"></translation>
+        <translation>Datum</translation>
     </message>
     <message>
-        <location filename="../settings.js" line="133"/>
+        <location filename="../scripts/settings.js" line="133"/>
         <source>English</source>
-        <translation type="unfinished"></translation>
+        <translation>Englisch</translation>
     </message>
 </context>
 <context>
     <name>xtube</name>
     <message>
-        <location filename="../xtube.js" line="18"/>
-        <location filename="../xtube.js" line="62"/>
         <source>Search </source>
-        <translation>Suche</translation>
+        <translation type="obsolete">Suche</translation>
     </message>
     <message>
-        <location filename="../xtube.js" line="39"/>
-        <location filename="../xtube.js" line="82"/>
         <source>Video Info</source>
-        <translation>Video Info</translation>
+        <translation type="obsolete">Video Info</translation>
     </message>
 </context>
 </TS>
