@@ -15,7 +15,7 @@ function restoreSettings() {
         Controller.setMediaPlayer(Settings.getSetting("mediaPlayer"));
     }
     else {
-        Settings.setSetting("mediaPlayer", "Media Player");
+        Settings.setSetting("mediaPlayer", qsTr("Media Player"));
         Controller.setMediaPlayer("Media Player");
     }
     YouTube.setPlaybackQuality(Settings.getSetting("playbackQuality"));
@@ -218,12 +218,19 @@ function youtubeSearch(query, order) {
     /* Perform a YouTube search and open video list window */
 
     var searchOrder = order;
-    if (order == "date") {
+    if (order == qsTr("date")) {
         searchOrder = "published";
     }
-    else if (order == "views") {
+    else if (order == qsTr("views")) {
         searchOrder = "viewCount";
     }
+    else if (order == qsTr("relevance")) {
+        searchOrder = "relevance";
+    }
+    else if (order == qsTr("rating")) {
+        searchOrder = "rating";
+    }
+    console.log(searchOrder)
 
     var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=none&q="
                      + escape(query).replace(" ", "+") + "&orderby=" + searchOrder);
