@@ -36,7 +36,7 @@ void YouTube::checkLogin() {
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
     if (!reply) {
         setCurrentUser("");
-        emit alert("Error obtaining access token");
+        emit alert(tr("Error obtaining access token"));
         return;
     }
 
@@ -46,10 +46,10 @@ void YouTube::checkLogin() {
 
     if (getAccessToken() == "BadAuthentication") {
         setCurrentUser("");
-        emit alert("Authentication failed");
+        emit alert(tr("Authentication failed"));
     }
     else {
-        emit alert("You are signed in to YouTube as '" + getCurrentUser() + "'");
+        emit alert(tr("You are signed in to YouTube as '") + getCurrentUser() + "'");
     }
     reply->deleteLater();
 }
@@ -111,7 +111,7 @@ void YouTube::setUploadUrl() {
         performVideoUpload();
     }
     else {
-        emit alert("Error - Server repsonse is: " + statusText);
+        emit alert(tr("Error - Server repsonse is: ") + statusText);
     }
 }
 
@@ -161,7 +161,7 @@ void YouTube::resumeVideoUpload() {
 void YouTube::abortVideoUpload() {
     uploadReply->abort();
     fileToBeUploaded->close();
-    emit uploadCompleted("<font color='yellow'>Upload aborted<font>");
+    emit uploadCompleted("<font color='yellow'>" + tr("Upload aborted") + "<font>");
 }
 
 void YouTube::uploadFinished() {
@@ -169,24 +169,24 @@ void YouTube::uploadFinished() {
 
     if (uploadReply->error()) {
         if (uploadReply->error() == QNetworkReply::OperationCanceledError) {
-            emit uploadCompleted("<font color='yellow'>Upload Aborted<font>");
+            emit uploadCompleted("<font color='yellow'>" + tr("Upload aborted") + "<font>");
             return;
         }
         else {
             int statusCode = uploadReply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
             if (statusCode == 308) {
                 if (uploadRetries > 0) {
-                    emit uploadCompleted("<font color='yellow'>Upload interrupted. Attempting to resume...<font>");
+                    emit uploadCompleted("<font color='yellow'>" + tr("Upload interrupted. Attempting to resume...") + "<font>");
                     QTimer::singleShot(3000, this, SLOT(resumeVideoUpload()));
                 }
                 else {
-                    emit uploadCompleted("<font color='red'>Upload failed<font>");
+                    emit uploadCompleted("<font color='red'>" + tr("Upload failed") + "<font>");
                 }
             }
         }
     }
     else {
-        emit uploadCompleted("<font color='green'>Upload is completed<font>");
+        emit uploadCompleted("<font color='green'>" + tr("Upload is completed") + "<font>");
     }
 }
 
@@ -217,7 +217,7 @@ void YouTube::postFinished() {
         emit postSuccessful();
     }
     else {
-        emit alert("Error - Server repsonse is: " + statusText);
+        emit alert(tr("Error - Server repsonse is: ") + statusText);
     }
     reply->deleteLater();
 }
@@ -376,7 +376,7 @@ void YouTube::parseVideoPage(QNetworkReply *reply) {
         index++;
     }
     if (videoUrl == "") {
-        emit alert("Error: Unable to retrieve video");
+        emit alert(tr("Error: Unable to retrieve video"));
     }
     else {
         emit gotVideoUrl(videoUrl);
